local BLOODTRADER_NPCID = 115264

local function IsBloodTrader()
  local guid = UnitGUID("npc")
  if not guid then return end
  local _, _, _, _, _, npcid = strsplit("-", guid)
  if not npcid then return end
  if tonumber(npcid) ~= BLOODTRADER_NPCID then return end
  return true
end

-- Hook GetMerchantItemInfo but only when it's called from within
-- FrameXML/MerchantFrame.lua's MerchantItemButton_OnModifiedClick() function
-- This makes the UI think that the Blood Trader only sells stacks of 1 for
-- the purposes of allowing split stacks.

local oldGetMerchantItemInfo = GetMerchantItemInfo
GetMerchantItemInfo = function(index)
  -- ignore if not blood trader
  if not IsBloodTrader() then return oldGetMerchantItemInfo(index) end

  -- get original values
  local name, texture, price, quantity, numAvailable, isUsable, extendedCost = oldGetMerchantItemInfo(index)
  
  -- only change quantity if GetMerchantItemInfo is being called from MerchantItemButton_OnModifiedClick
  local stack = debugstack(2,1,1)
  if stack:match("MerchantItemButton_OnModifiedClick") then quantity = 1 end
  
  -- return values with quantity possibly modified
  return name, texture, price, quantity, numAvailable, isUsable, extendedCost  
end
